@@ -1,4 +1,4 @@
-##############################################################################
+#############################################################################
 #
 # Copyright (c) 2006 Zope Corporation and Contributors.
 # All Rights Reserved.
@@ -12,6 +12,7 @@
 #
 ##############################################################################
 
+import optparse
 import os
 import shutil
 import subprocess
@@ -40,7 +41,7 @@ def _relative(path, to):
             break
         to = d
     
-    while path and path != to:
+    while path and path != to and path != '/':
         path, base = os.path.split(path)
         if base:
             rel.insert(0, base)
@@ -52,6 +53,14 @@ def source_release(args=None):
     if args is None:
         args = sys.argv[1:]
 
+    # set up command line options
+    parser = optparse.OptionParser()
+    parser.add_option("-n", "--name", dest="filename",
+        help="create custom named files", default="None")
+
+    # retrieve options
+    (options, args) = parser.parse_args(args)
+
     url = args.pop(0)
     config = args.pop(0)
 
@@ -62,12 +71,17 @@ def source_release(args=None):
         clopts.append((section, option, value))
     
     name = url.split('/')[-1]
+
+    # use optparse to find custom filename
+    if options.filename != 'None':
+        name = options.filename
+
     t1 = tempfile.mkdtemp('source-release1')
     t2 = tempfile.mkdtemp('source-release2')
     co1 = os.path.join(t1, name)
     co2 = os.path.join(t2, name)
     here = os.getcwd()
-    print 'Creating source release.'
+    print 'Creating source release in %s.tgz' % name
     sys.stdout.flush()
     try:
 
@@ -85,7 +99,8 @@ def source_release(args=None):
         eggs_directory = buildout['buildout']['eggs-directory']
         reggs = _relative(eggs_directory, co1)
         if reggs is None:
-            print 'Invalid eggs directory', eggs_directory
+            print 'Invalid eggs directory (perhaps not a relative path)', \
+                eggs_directory
             sys.exit(0)
 
         buildout.bootstrap([])
